diff --git a/adapters/oidc/spring-boot2/pom.xml b/adapters/oidc/spring-boot2/pom.xml
index 66a89707da..3433b332eb 100755
--- a/adapters/oidc/spring-boot2/pom.xml
+++ b/adapters/oidc/spring-boot2/pom.xml
@@ -77,7 +77,7 @@
org.springframework
spring-core
- 5.0.2.RELEASE
+ ${spring.version}
provided
diff --git a/pom.xml b/pom.xml
index 8d70df5f1b..934f872d4e 100644
--- a/pom.xml
+++ b/pom.xml
@@ -192,10 +192,8 @@
9.0.16
- 1.5.20.RELEASE
- 2.1.3.RELEASE
- 2.2.0.RELEASE
- 2.3.0.RELEASE
+ 2.4.13
+ 2.6.1
0.12.0.RELEASE
diff --git a/testsuite/integration-arquillian/HOW-TO-RUN.md b/testsuite/integration-arquillian/HOW-TO-RUN.md
index 1431e87929..21fbf43ab2 100644
--- a/testsuite/integration-arquillian/HOW-TO-RUN.md
+++ b/testsuite/integration-arquillian/HOW-TO-RUN.md
@@ -472,18 +472,18 @@ mvn -f testsuite/integration-arquillian/tests/other/console/pom.xml \
## Spring Boot adapter tests
-Currently we are testing Spring Boot with three different containers `Tomcat 8`, `Undertow` and `Jetty [9.2, 9.3, 9.4]`. We are testing two versions of Spring Boot 1.5.x and 2.1.x. All versions are specified in [root pom.xml](../../pom.xml) (see properties `spring-boot15.version` and `spring-boot21.version`).
-
-To run tests execute following command. Default version of Spring Boot is 1.5.x, to run tests with version 2.1.x add profile `-Pspringboot21`
+Currently, we are testing Spring Boot with three different containers `Tomcat 8`, `Undertow` and `Jetty 9.4`.
+We are testing various versions of Spring Boot 2.x. All versions are specified in [root pom.xml](../../pom.xml) (i.e. see properties `spring-boot24.version` and `spring-boot26.version`).
+To run tests execute following command. Default version of Spring Boot is 2.4.x, to run tests with version 2.6.x add profile `-Pspringboot26`.
```
mvn -f testsuite/integration-arquillian/tests/other/springboot-tests/pom.xml \
clean test \
- -Dadapter.container=[tomcat|undertow|jetty92|jetty93|jetty94] \
- [-Pspringboot21]
+ -Dadapter.container=[tomcat|undertow|jetty94] \
+ [-Pspringboot26]
```
-Note: Spring Boot 21 doesn't work with jetty92 and jetty93, only jetty94 is tested.
+ **Note:** Spring Boot 2.x doesn't work with `jetty92` and `jetty93`, only `jetty94` is tested.
## Base UI tests
Similarly to Admin Console tests, these tests are focused on UI, specifically on the parts of the server that are accessed by an end user (like Login page, or Account Console).
diff --git a/testsuite/integration-arquillian/test-apps/spring-boot-adapter-app/pom.xml b/testsuite/integration-arquillian/test-apps/spring-boot-adapter-app/pom.xml
index d71d59e044..c659d3f057 100644
--- a/testsuite/integration-arquillian/test-apps/spring-boot-adapter-app/pom.xml
+++ b/testsuite/integration-arquillian/test-apps/spring-boot-adapter-app/pom.xml
@@ -17,7 +17,7 @@
1.8
${jetty94.version}
- 2.3
+ 2.4
false
keycloak-tomcat-adapter
@@ -44,431 +44,43 @@
org.springframework.boot
spring-boot-starter-web
+
+
+ org.keycloak
+ keycloak-spring-boot-2-adapter
+
- spring.boot.1.5
+ spring.boot.2.4
true
-
springboot-version
- 1.5
+ 2.4
- ${spring-boot15.version}
+ ${spring-boot24.version}
-
-
-
-
- org.eclipse.jetty
- apache-jsp
- ${jetty.version}
-
-
- org.eclipse.jetty
- apache-jstl
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-alpn-client
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-alpn-java-client
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-alpn-java-server
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-alpn-server
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-annotations
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-ant
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-client
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-continuation
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-deploy
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-hazelcast
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-http
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-http-spi
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-infinispan
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-io
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-jaas
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-jaspi
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-jmx
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-jndi
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-nosql
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-plus
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-proxy
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-quickstart
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-rewrite
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-runner
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-security
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-server
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-servlet
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-servlets
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-spring
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-start
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-unixsocket
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-util
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-util-ajax
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-webapp
- ${jetty.version}
-
-
- org.eclipse.jetty
- jetty-xml
- ${jetty.version}
-
-
- org.eclipse.jetty.cdi
- cdi-core
- ${jetty.version}
-
-
- org.eclipse.jetty.cdi
- cdi-servlet
- ${jetty.version}
-
-
- org.eclipse.jetty.fcgi
- fcgi-client
- ${jetty.version}
-
-
- org.eclipse.jetty.fcgi
- fcgi-server
- ${jetty.version}
-
-
- org.eclipse.jetty.gcloud
- jetty-gcloud-session-manager
- ${jetty.version}
-
-
- org.eclipse.jetty.http2
- http2-client
- ${jetty.version}
-
-
- org.eclipse.jetty.http2
- http2-common
- ${jetty.version}
-
-
- org.eclipse.jetty.http2
- http2-hpack
- ${jetty.version}
-
-
- org.eclipse.jetty.http2
- http2-http-client-transport
- ${jetty.version}
-
-
- org.eclipse.jetty.http2
- http2-server
- ${jetty.version}
-
-
- org.eclipse.jetty.memcached
- jetty-memcached-sessions
- ${jetty.version}
-
-
- org.eclipse.jetty.osgi
- jetty-osgi-boot
- ${jetty.version}
-
-
- org.eclipse.jetty.osgi
- jetty-osgi-boot-jsp
- ${jetty.version}
-
-
- org.eclipse.jetty.osgi
- jetty-osgi-boot-warurl
- ${jetty.version}
-
-
- org.eclipse.jetty.osgi
- jetty-httpservice
- ${jetty.version}
-
-
- org.eclipse.jetty.websocket
- javax-websocket-client-impl
- ${jetty.version}
-
-
- org.eclipse.jetty.websocket
- javax-websocket-server-impl
- ${jetty.version}
-
-
- org.eclipse.jetty.websocket
- websocket-api
- ${jetty.version}
-
-
- org.eclipse.jetty.websocket
- websocket-client
- ${jetty.version}
-
-
- org.eclipse.jetty.websocket
- websocket-common
- ${jetty.version}
-
-
- org.eclipse.jetty.websocket
- websocket-server
- ${jetty.version}
-
-
- org.eclipse.jetty.websocket
- websocket-servlet
- ${jetty.version}
-
-
-
-
-
-
- org.keycloak
- keycloak-spring-boot-adapter
-
-
-
- spring.boot.2.1
+ spring.boot.2.6
springboot-version
- 2.1
+ 2.6
- ${spring-boot21.version}
+ ${spring-boot26.version}
-
-
-
-
- org.eclipse.jetty
- jetty-bom
- ${jetty.version}
- pom
-
-
-
-
-
-
- org.keycloak
- keycloak-spring-boot-2-adapter
-
-
-
-
-
- spring.boot.2.2
-
-
-
- springboot-version
- 2.2
-
-
-
-
- ${spring-boot22.version}
-
-
-
-
-
- org.eclipse.jetty
- jetty-bom
- ${jetty.version}
- pom
-
-
-
-
-
-
- org.keycloak
- keycloak-spring-boot-2-adapter
-
-
-
-
-
- spring.boot.2.3
-
-
-
- springboot-version
- 2.3
-
-
-
-
- ${spring-boot23.version}
-
-
-
-
-
- org.eclipse.jetty
- jetty-bom
- ${jetty.version}
- pom
-
-
-
-
-
-
- org.keycloak
- keycloak-spring-boot-2-adapter
-
-
@@ -631,6 +243,12 @@
pom
import
+
+ org.eclipse.jetty
+ jetty-bom
+ ${jetty.version}
+ pom
+
diff --git a/testsuite/integration-arquillian/tests/other/springboot-tests/pom.xml b/testsuite/integration-arquillian/tests/other/springboot-tests/pom.xml
index 1509188103..800a73ed1b 100644
--- a/testsuite/integration-arquillian/tests/other/springboot-tests/pom.xml
+++ b/testsuite/integration-arquillian/tests/other/springboot-tests/pom.xml
@@ -15,7 +15,7 @@
tomcat
- 1.5
+ 2.4
5006
n
@@ -201,24 +201,18 @@
+
- springboot21
+ springboot24
- 2.1
+ 2.4
- springboot22
+ springboot26
- 2.2
-
-
-
-
- springboot23
-
- 2.3
+ 2.6
diff --git a/misc/scripts/upgrade-wildfly/lib/wildfly/upgrade/__init__.py b/misc/scripts/upgrade-wildfly/lib/wildfly/upgrade/__init__.py
index f54e140537..3654304a84 100644
--- a/misc/scripts/upgrade-wildfly/lib/wildfly/upgrade/__init__.py
+++ b/misc/scripts/upgrade-wildfly/lib/wildfly/upgrade/__init__.py
@@ -663,10 +663,8 @@ _keycloakSpecificProperties = [
"tomcat7.version",
"tomcat8.version",
"tomcat9.version",
- "spring-boot15.version",
- "spring-boot21.version",
- "spring-boot22.version",
- "spring-boot23.version",
+ "spring-boot24.version",
+ "spring-boot26.version",
"webauthn4j.version",
"org.apache.kerby.kerby-asn1.version",
]
@@ -771,7 +769,7 @@ _keycloakToWildflyProperties = {
# Skip "frontend.plugin.version" since Keycloak specific
# Skip "docker.maven.plugin.version" since Keycloak specific
# Skip "tomcat7.version", "tomcat8.version", and "tomcat9.version" since Keycloak specific
# Skip "spring-boot15.version", "spring-boot21.version", "spring-boot22.version", and "spring-boot23.version" since Keycloak specific
# Skip "webauthn4j.version" since Keycloak specific
# Skip "org.apache.kerby.kerby-asn1.version" since Keycloak specific
}
@@ -771,7 +769,7 @@ _keycloakToWildflyProperties = {
# Skip "docker.maven.plugin.version" since Keycloak specific
# Skip "tomcat7.version", "tomcat8.version", and "tomcat9.version" since Keycloak specific
- # Skip "spring-boot15.version", "spring-boot21.version", "spring-boot22.version", and "spring-boot23.version" since Keycloak specific
+ # Skip "spring-boot24.version" and "spring-boot26.version" since Keycloak specific
# Skip "webauthn4j.version" since Keycloak specific
# Skip "org.apache.kerby.kerby-asn1.version" since Keycloak specific